Module socialization.bot.message
================================

Functions
---------

    
`message_from_raw(raw_data: dict) ‑> socialization.bot.message.Message`
:   

Classes
-------

`Message(type: socialization.bot.message.MessageType, body=None, channel: str = '', to: list = [], sender: str = '', recipient_count: int = 0, id: str = '', origin: str = 'Bot', raw=None)`
:   

`MessageType(value, names=None, *, module=None, qualname=None, type=None, start=1)`
:   This is enumeration of message types.

    ### Ancestors (in MRO)

    * enum.Enum

    ### Class variables

    `FILE`
    :

    `IMAGE`
    :

    `TEXT`
    :